\name{aRTconn}

\docType{class}

\alias{aRTconn-class}
\alias{initialize,aRTconn-method}
\alias{aRTconn}
\alias{openConn}

\title{Class aRTconn}
\description{Class that stores a virtual DBMA connection and manipulates databases.
The connection is virtual because each time a function is called, it connects, does
something and then disconnects.}

\section{Objects from the Class}{
Objects can be created by calls of the form \code{openConn(user, password, port, host)}.
}

\section{Arguments}{
  \describe{
  \item{user}{User of the DBMS. The default is the username logged in the system.}
  \item{password}{The password, default is \dQuote{}.}
  \item{port}{Port of the connection. The default depends on the DBMS.}
  \item{host}{Host to connect, default is \dQuote{}, that means \dQuote{localhost}.}
  \item{name}{The connection's name. See below.}
  }
}

\section{Extends}{
Class \code{aRTcomponent}, directly.
}

\section{Methods}{
  \describe{
	\item{createDb:}{Create a new database and returns a connection to it.}
	\item{deleteDb:}{Remove a database from the DBMS.}
	\item{openDb:}{Open an existent database.}
    \item{showDbs:}{List the available databases.}
	\item{addPermission:}{Grant permissions on the DBMS to a given user.}
	\item{getPermissions:}{List the permissions for all users of a DBMS.}
	\item{dropUser:}{Remove permissions of a user in the DBMS.}
  }
}

\section{Connection names}{
aRT supports config files for storing information about the user's connections.
Each user can have his/her own config file, called .aRTrc, and located in the root
of his/her own home directory. An example of file is shown below:

 [root]\cr
 user=root\cr
 password=abc123\cr
 dbms=mysql\cr
 [pataxo]\cr
 host=pataxo.est.ufpr.br\cr
 user=pedro\cr
\cr

Each line starting with \dQuote{[} and ending with \dQuote{]}
are names for the connections, which can be used in the \dQuote{name}
argument of \code{openConn()}.
In this file we have two connections, one called \dQuote{root},
and the other \dQuote{pataxo}.
The lines below a name describe the parameters for that connection.
The missing arguments of a connection
in the file can be used as parameters in \code{openConn()}.

WARNING: If this file contains passwords or any other confidential information, 
then set the permissions correctly (reading permission only to its owner).

}

\author{Marcos Aurelio Carrero, Pedro Ribeiro de Andrade}

\seealso{
  See \code{\link{aRT}} the package organization.
}

\keyword{classes}
% vim: syntax=tex
